summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorDaniel Caujolle-Bert <f1rmb@users.sourceforge.net>2002-05-19 10:35:18 +0000
committerDaniel Caujolle-Bert <f1rmb@users.sourceforge.net>2002-05-19 10:35:18 +0000
commit3f34bdf9c2664b667fe0714602e6794e84f9b463 (patch)
tree6d6cc7144e7c8d413ef40d0e316f516294340b4f /src
parent8fba6cb848cf8da9357fdb122d473c6f8b85b9e5 (diff)
downloadxine-lib-3f34bdf9c2664b667fe0714602e6794e84f9b463.tar.gz
xine-lib-3f34bdf9c2664b667fe0714602e6794e84f9b463.tar.bz2
ximage creation for shm check use supported image format.
CVS patchset: 1908 CVS date: 2002/05/19 10:35:18
Diffstat (limited to 'src')
-rw-r--r--src/video_out/video_out_xv.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/video_out/video_out_xv.c b/src/video_out/video_out_xv.c
index b8427ed01..27ce4c5eb 100644
--- a/src/video_out/video_out_xv.c
+++ b/src/video_out/video_out_xv.c
@@ -17,7 +17,7 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*
- * $Id: video_out_xv.c,v 1.115 2002/05/07 19:20:16 f1rmb Exp $
+ * $Id: video_out_xv.c,v 1.116 2002/05/19 10:35:18 f1rmb Exp $
*
* video_out_xv.c, X11 video extension interface for xine
*
@@ -1448,10 +1448,10 @@ vo_driver_t *init_video_out_plugin (config_values_t *config, void *visual_gen) {
/*
* try to create a shared image
* to find out if MIT shm really works
*/
-
- myimage = create_ximage (this, &myshminfo, 100, 100, IMGFMT_YV12);
+ myimage = create_ximage (this, &myshminfo, 100, 100,
+ (this->xv_format_yv12 != 0) ? IMGFMT_YV12 : IMGFMT_YUY2);
dispose_ximage (this, &myshminfo, myimage);
this->deinterlace_method = config->register_enum (config, "video.deinterlace_method", 4,
@@ -1448,10 +1448,10 @@ vo_driver_t *init_video_out_plugin (config_values_t *config, void *visual_gen) {
/*
* try to create a shared image
- * to find out if MIT shm really works
+ * to find out if MIT shm really works, using supported format
*/